@@ -33,8 +33,8 @@ __all__ = [
     "ParseFileFlags",                               # main.py
     "ForAll", "Exists", "bitvec_to_substates",      # utils.py
     "get_example", "get_theory", "run_test",
-    "BuildModule", "BuildProject", "BuildExample",  # builder.py
-    "BuildModule", "BuildExample", "main",
+    "BuildModule", "BuildProject",  # builder.py
+    "BuildModule", "main",
     "ModelConstraints",
     "Syntax",
 ]
@@ -53,10 +53,8 @@ except ImportError:
     # If we can't import, don't add jupyter components to __all__
     pass
 
-# Import model as a whole
-from .model import (
-    ModelConstraints,
-)
+# Import model components
+from .models.constraints import ModelConstraints
 
 # Import syntactic as a whole
 from .syntactic import (
@@ -77,7 +75,6 @@ from .utils import (
 from .builder import (
     BuildModule,
     BuildProject,
-    BuildExample,
 )
 
 # Import specific items from __main__
