@@ -9,12 +9,10 @@ import z3
 import sys
 import os
 
-from model_checker.model import (
-    SemanticDefaults,
-    PropositionDefaults,
-    ModelConstraints,
-    ModelDefaults,
-)
+from model_checker.models.semantic import SemanticDefaults
+from model_checker.models.proposition import PropositionDefaults
+from model_checker.models.constraints import ModelConstraints
+from model_checker.models.structure import ModelDefaults
 from model_checker.syntactic import (
     OperatorCollection,
     Syntax,
@@ -28,6 +26,7 @@ from model_checker.builder.z3_utils import (
     extract_model_values,
     find_next_model as find_next_z3_model
 )
+from model_checker.theory_lib.logos import semantic
 
 class BuildExample:
     """Handles the creation and evaluation of a single model checking example.
@@ -115,6 +114,9 @@ class BuildExample:
         )
         
         # Create model structure
+        # NOTE: This model building process is partially duplicated in
+        # iterate/core.py:_build_new_model_structure() for MODEL 2+ construction.
+        # If this process changes, review the iterator implementation as well.
         self.model_structure = self.model_structure_class(
             self.model_constraints,
             self.settings,
