@@ -14,7 +14,7 @@ import sys
 import threading
 
 # Relative imports
-from model_checker.builder.progress import Spinner
+from model_checker.output.progress import UnifiedProgress, Spinner
 from model_checker.syntactic import Syntax
 from model_checker.builder.serialize import (
     serialize_semantic_theory,
@@ -43,6 +43,47 @@ class BuildModule:
         maximize (bool): Whether to maximize the model size
     """
 
+    def _discover_theory_module(self, theory_name, semantic_theory):
+        """Dynamically discover the theory module name from semantic theory.
+        
+        This method follows the Theory Agnostic Principle by extracting the module
+        name from the semantic theory's components rather than using hardcoded mappings.
+        
+        Args:
+            theory_name: Display name of the theory (e.g., "BernardChampollion")
+            semantic_theory: Dictionary containing theory components
+            
+        Returns:
+            str: Module name (e.g., "exclusion") or None if not found
+        """
+        # Try to extract module name from semantics class
+        semantics_class = semantic_theory.get("semantics")
+        if semantics_class and hasattr(semantics_class, "__module__"):
+            module_path = semantics_class.__module__
+            # Extract theory module name from path
+            # e.g., "model_checker.theory_lib.exclusion.semantic" -> "exclusion"
+            parts = module_path.split('.')
+            if len(parts) >= 3 and parts[1] == "theory_lib":
+                return parts[2]
+        
+        # Try model class as fallback
+        model_class = semantic_theory.get("model")
+        if model_class and hasattr(model_class, "__module__"):
+            module_path = model_class.__module__
+            parts = module_path.split('.')
+            if len(parts) >= 3 and parts[1] == "theory_lib":
+                return parts[2]
+        
+        # Try proposition class as final fallback
+        prop_class = semantic_theory.get("proposition")
+        if prop_class and hasattr(prop_class, "__module__"):
+            module_path = prop_class.__module__
+            parts = module_path.split('.')
+            if len(parts) >= 3 and parts[1] == "theory_lib":
+                return parts[2]
+        
+        return None
+    
     def __init__(self, module_flags):
         """Initialize BuildModule with module flags containing configuration.
         
@@ -88,6 +129,34 @@ class BuildModule:
         # Set attributes for backward compatibility
         for key, value in self.general_settings.items():
             setattr(self, key, value)
+            
+        # Initialize output manager if save_output is enabled
+        from model_checker.output import OutputManager, InteractiveSaveManager, ConsoleInputProvider
+        
+        # Create interactive manager if save_output is enabled
+        self.interactive_manager = None
+        if self.save_output:
+            # Create console input provider for production use
+            input_provider = ConsoleInputProvider()
+            self.interactive_manager = InteractiveSaveManager(input_provider)
+            # Check if interactive flag is set
+            if hasattr(self.module_flags, 'interactive') and self.module_flags.interactive:
+                # Interactive flag specified - set mode directly
+                self.interactive_manager.set_mode('interactive')
+            else:
+                # No interactive flag - prompt for mode
+                self.interactive_manager.prompt_save_mode()
+        
+        self.output_manager = OutputManager(
+            save_output=self.save_output,
+            mode=getattr(self.module_flags, 'output_mode', 'batch'),
+            sequential_files=getattr(self.module_flags, 'sequential_files', 'multiple'),
+            interactive_manager=self.interactive_manager
+        )
+        
+        # Create output directory if needed
+        if self.output_manager.should_save():
+            self.output_manager.create_output_directory()
 
     def _is_generated_project(self, module_dir):
         """Detect if module is from a generated project.
@@ -361,7 +430,7 @@ class BuildModule:
                 - success (bool): True if model found within max time, False otherwise
                 - runtime (float): Time taken to attempt finding the model
         """
-        from model_checker.model import ModelConstraints
+        from model_checker.models.constraints import ModelConstraints
 
         premises, conclusions, settings = example_case
         semantics_class = semantic_theory["semantics"]
@@ -411,7 +480,7 @@ class BuildModule:
         Returns:
             tuple: (success, runtime)
         """
-        from model_checker.model import ModelConstraints
+        from model_checker.models.constraints import ModelConstraints
         from model_checker.syntactic import Syntax
         from model_checker.builder.serialize import deserialize_semantic_theory
         
@@ -576,7 +645,7 @@ class BuildModule:
         3. Compares semantic theories by finding maximum model sizes
         4. Prints results showing which theories could handle larger models
         """
-        from model_checker.model import ModelConstraints
+        from model_checker.models.constraints import ModelConstraints
         
         print()
         for example_name, example_case in self.example_range.items():
@@ -594,6 +663,29 @@ class BuildModule:
             self.compare_semantics(example_theory_tuples)
             print(f"\n{'='*40}")
 
+    def _prompt_for_iterations(self):
+        """Prompt user for number of iterations in interactive mode.
+        
+        Returns:
+            int: Number of additional models to find (0 means no more)
+        """
+        print("\nDo you want to find another model?")
+        response = input("Enter a number to iterate or hit return to continue: ").strip()
+        
+        if not response:
+            # User hit return - continue to next example
+            return 0
+            
+        try:
+            num_iterations = int(response)
+            if num_iterations < 0:
+                print("Please enter a positive number.")
+                return self._prompt_for_iterations()
+            return num_iterations
+        except ValueError:
+            print("Please enter a valid number or hit return to continue.")
+            return self._prompt_for_iterations()
+
     def process_example(self, example_name, example_case, theory_name, semantic_theory):
         """Process a single model checking example with a fresh Z3 context.
         
@@ -646,57 +738,122 @@ class BuildModule:
         if dictionary:
             example_case = self.translate(example_case, dictionary)
         
+        # Get the iterate count early to set up progress tracking
+        iterate_count = example_case[2].get('iterate', 1)
+        
+        # If iterate=1, no progress tracking needed
+        if iterate_count == 1:
+            # Create and solve the example without progress tracking
+            example = BuildExample(self, semantic_theory, example_case, theory_name)
+            self._capture_and_save_output(example, example_name, theory_name)
+            return example
+        
+        # Create unified progress tracker for all models
+        max_time = example_case[2].get('max_time', 60.0)
+        progress = UnifiedProgress(
+            total_models=iterate_count,
+            max_time=max_time  # Single timeout for all operations
+        )
+        
+        # Add vertical space before first progress bar
+        print()
+        
+        # Capture Model 1 start time BEFORE any work
+        model_1_start = time.time()
+        
+        # Start progress for first model with timing
+        progress.start_model_search(1, start_time=model_1_start)
+        
         # Create and solve the example
         example = BuildExample(self, semantic_theory, example_case, theory_name)
         
+        # Update progress
+        progress.model_checked()
+        
+        # Store timing reference for iteration report
+        # The model already has z3_model_runtime for solver time
+        # Add total search time for consistency
+        example.model_structure._search_start_time = model_1_start
+        example.model_structure._total_search_time = time.time() - model_1_start
+        
         # Check if a model was found
         if not example.model_structure.z3_model_status:
-            example.print_model(example_name, theory_name)
+            progress.complete_model_search(found=False)
+            progress.finish()
+            self._capture_and_save_output(example, example_name, theory_name)
             return example
         
-        # Get the iterate count
-        iterate_count = example.settings.get('iterate', 1)
+        # Complete first model search
+        progress.complete_model_search(found=True)
         
-        # Print the first model with numbering if we're iterating
+        # Add vertical space after first progress bar
+        print()
+        
+        # Pass progress to example for iterator to use
         if iterate_count > 1:
-            print(f"\nMODEL 1/{iterate_count}")
-            
-        example.print_model(example_name, theory_name)
+            example._unified_progress = progress
         
-        # Return if we don't need to iterate
-        if iterate_count <= 1:
-            return example
+        # Handle iteration for interactive mode first to get correct count
+        if self.interactive_manager and self.interactive_manager.is_interactive():
+            # First, print the model without numbering
+            self._capture_and_save_output(example, example_name, theory_name)
+            
+            # Then prompt for iterations
+            user_iterations = self._prompt_for_iterations()
+            if user_iterations == 0:
+                progress.finish()
+                return example
+            # Override iterate count with user's choice (plus 1 for the model already shown)
+            iterate_count = user_iterations + 1
+            
+            # Update progress with new total
+            progress.total_models = iterate_count
+            example._unified_progress = progress
+        else:
+            # In batch mode, just print the first model without numbering
+            # The numbering starts with the second model from iteration
+            self._capture_and_save_output(example, example_name, theory_name)
+            
+            # Return if we don't need to iterate in batch mode
+            if iterate_count <= 1:
+                progress.finish()
+                return example
+            
+            # Add vertical space after the first model before iteration starts
+            print()
         
         try:
             # Get the theory-specific iterate_example function
             try:
-                # Map display name to module name
-                # This mapping handles cases where theory_name is a display name (like "Brast-McKie")
-                # rather than the actual module name used for imports
-                theory_display_to_module = {
-                    "Brast-McKie": "logos",  # Brast-McKie is the logos theory
-                    "Exclusion": "exclusion",
-                    "unilateral_theory": "exclusion",  # Exclusion theory's internal name
-                    "Imposition": "imposition",
-                    "Fine": "imposition",  # Fine is the imposition theory
-                    "Bimodal": "bimodal",
-                    "Logos": "logos"
-                }
+                # Dynamically discover the theory module from the semantic theory
+                module_name = self._discover_theory_module(theory_name, semantic_theory)
                 
-                # Get the module name from the mapping or use the theory name directly
-                module_name = theory_display_to_module.get(theory_name, theory_name.lower())
+                if not module_name:
+                    # Fallback: try theory_name as module name directly
+                    module_name = theory_name.lower()
                 
-                # Import the theory module to access its iterate_example function
+                # Import the theory module to access its iterate function
                 theory_module = importlib.import_module(f"model_checker.theory_lib.{module_name}")
-                if not hasattr(theory_module, 'iterate_example'):
-                    raise ImportError(f"Theory module '{module_name}' does not provide an iterate_example function")
                 
-                theory_iterate_example = theory_module.iterate_example
+                # Check for generator version first
+                if hasattr(theory_module, 'iterate_example_generator'):
+                    theory_iterate_example = theory_module.iterate_example_generator
+                elif hasattr(theory_module, 'iterate_example'):
+                    theory_iterate_example = theory_module.iterate_example
+                else:
+                    raise ImportError(f"Theory module '{module_name}' does not provide an iterate_example function")
             except ImportError as e:
                 print(f"Error: {e}", file=sys.stderr)
                 return example
             
-            # Find additional models using the theory-specific iterate_example function
+            # Check if theory supports generator interface
+            if hasattr(theory_iterate_example, '__wrapped__') and \
+               hasattr(theory_iterate_example.__wrapped__, 'returns_generator'):
+                # Use generator interface for incremental display
+                self._run_generator_iteration(example, theory_iterate_example, example_name, theory_name, iterate_count)
+                return example
+            
+            # Fallback to list-based iteration
             model_structures = theory_iterate_example(example, max_iterations=iterate_count)
             
             # Skip the first model which is already printed
@@ -714,13 +871,13 @@ class BuildModule:
                     # For the first model, just print it
                     if distinct_count == 1:
                         # Print model header
-                        print(f"\nMODEL {distinct_count}/{expected_total}")
+                        print(f"MODEL {distinct_count}/{expected_total}")
                         
                         # Set the current model structure
                         example.model_structure = structure
                         
                         # Print the model
-                        example.print_model(f"{example_name}", theory_name)
+                        self._capture_and_save_output(example, example_name, theory_name, model_num=distinct_count)
                     else:
                         # For subsequent models, first print the differences then the model
                         # Print detailed differences between this model and the previous one
@@ -751,9 +908,6 @@ class BuildModule:
                         
                         # Now print the differences
                         try:
-                            # Force setting to properly colorize output
-                            print("\033[1m\033[0m", end="")  # Force ANSI escape sequence processing
-                            
                             # Each theory must provide its own print_model_differences method
                             if hasattr(structure, 'print_model_differences'):
                                 structure.print_model_differences()
@@ -763,7 +917,7 @@ class BuildModule:
                             print(f"Error printing model differences: {str(e)}")
                                 
                         # Print model header
-                        print(f"\nMODEL {distinct_count}/{expected_total}")
+                        print(f"MODEL {distinct_count}/{expected_total}")
                         
                         # Set the current model structure
                         example.model_structure = structure
@@ -773,7 +927,7 @@ class BuildModule:
                             structure._is_last_model = True
                             
                         # Print the model
-                        example.print_model(f"{example_name}", theory_name)
+                        self._capture_and_save_output(example, example_name, theory_name, model_num=distinct_count)
                     
                 # For isomorphic models that are skipped, we could optionally add a subtle indicator
                 # Uncomment to show skipped models
@@ -792,7 +946,7 @@ class BuildModule:
                     for msg in debug_messages:
                         print(msg)
             
-            print(f"\nFound {distinct_count}/{expected_total} distinct models.")
+            # Termination info is now handled by the iterator's detailed report
             
             # Check if there was any partial output
             if hasattr(example.model_structure, 'model_differences') and not hasattr(example.model_structure, '_is_last_model'):
@@ -803,8 +957,153 @@ class BuildModule:
             print(f"Error during iteration: {str(e)}")
             import traceback
             print(traceback.format_exc())
+        finally:
+            # Ensure progress is cleaned up
+            progress.finish()
         
         return example
+    
+    def _run_generator_iteration(self, example, theory_iterate_example, example_name, theory_name, iterate_count):
+        """Run iteration using generator interface for incremental display.
+        
+        Args:
+            example: The BuildExample instance
+            theory_iterate_example: Theory-specific iterate function with generator support
+            example_name: Name of the example being run
+            theory_name: Name of the theory
+            iterate_count: Total number of models to find
+        """
+        # Get generator from theory
+        model_generator = theory_iterate_example(example, max_iterations=iterate_count)
+        
+        # Track distinct models
+        distinct_count = 0  # Will increment when we find the first additional model
+        previous_model = example.model_structure
+        
+        try:
+            # Process models as they're yielded
+            for i, structure in enumerate(model_generator, start=2):
+                # Skip isomorphic models in display
+                if hasattr(structure, '_is_isomorphic') and structure._is_isomorphic:
+                    continue
+                    
+                distinct_count += 1
+                
+                # Always print differences from previous model (except for the first additional model)
+                if previous_model:
+                    # Print differences using structure's method
+                    if hasattr(structure, 'print_model_differences'):
+                        structure.print_model_differences()
+                    else:
+                        print("\n=== DIFFERENCES FROM PREVIOUS MODEL ===")
+                        if hasattr(structure, 'model_differences') and structure.model_differences:
+                            # Basic difference display if no custom method
+                            from model_checker.iterate.metrics import ResultFormatter
+                            formatter = ResultFormatter()
+                            diff_report = formatter.format_difference_report(structure.model_differences)
+                            print(diff_report)
+                        else:
+                            print("(No differences calculated)")
+                
+                # Print model header - now showing correct numbering (2/4, 3/4, 4/4)
+                print(f"MODEL {distinct_count + 1}/{iterate_count}")
+                
+                # Update example with new model
+                example.model_structure = structure
+                
+                # Display model immediately
+                self._capture_and_save_output(example, example_name, theory_name, model_num=distinct_count)
+                
+                # Add extra vertical space after non-isomorphic models (except for the last one)
+                # Only add space if we're not at the last model we'll actually find
+                # Note: We can't know if more models exist until we try to get the next one
+                # So we always add space unless we've reached the requested count
+                if distinct_count < iterate_count - 1:
+                    print()
+                
+                # Update previous model for next iteration
+                previous_model = structure
+                
+        except StopIteration:
+            # Normal termination - no more models found
+            pass
+        except Exception as e:
+            print(f"Error during iteration: {e}", file=sys.stderr)
+            import traceback
+            traceback.print_exc()
+        
+        # Termination info is now handled by the iterator's detailed report
+        
+    def _get_termination_info(self, example, found_count, requested_count):
+        """Generate comprehensive termination message.
+        
+        Args:
+            example: BuildExample with iterator information
+            found_count: Number of distinct models found
+            requested_count: Number of models requested
+            
+        Returns:
+            str: Formatted termination message
+        """
+        # Get iterator if available
+        iterator = getattr(example, '_iterator', None)
+        if not iterator:
+            return f"Found {found_count}/{requested_count} distinct models."
+        
+        # Get basic stats
+        skipped_count = getattr(iterator, 'isomorphic_model_count', 0)
+        elapsed_time = 0.0
+        if hasattr(iterator, 'termination_manager'):
+            elapsed_time = iterator.termination_manager.get_elapsed_time()
+        
+        # Base message with stats
+        base_msg = f"Found {found_count}/{requested_count} distinct models "
+        base_msg += f"(skipped {skipped_count} isomorphic models in {elapsed_time:.1f}s)."
+        
+        # Add termination reason
+        if found_count == requested_count:
+            reason = "Successfully found all requested models."
+        else:
+            reason = self._get_termination_reason(iterator, found_count, requested_count)
+        
+        return f"{base_msg}\n{reason}"
+    
+    def _get_termination_reason(self, iterator, found_count, requested_count):
+        """Determine why iteration stopped.
+        
+        Returns formatted reason string.
+        """
+        # Check debug messages for specific reasons
+        debug_messages = iterator.get_debug_messages() if hasattr(iterator, 'get_debug_messages') else []
+        
+        # Debug: print messages to understand termination
+        # import sys
+        # print(f"DEBUG: Found {len(debug_messages)} debug messages:", file=sys.stderr)
+        # for msg in debug_messages:
+        #     print(f"  - {msg}", file=sys.stderr)
+        
+        # Look for specific termination indicators
+        for msg in reversed(debug_messages):  # Check most recent first
+            if "No more models found" in msg and "unsat" in msg:
+                return "Search complete: No more non-isomorphic models exist."
+            elif "timeout" in msg.lower() and "reached" in msg.lower():
+                # Extract timeout value from message if present
+                import re
+                timeout_match = re.search(r'(\d+\.?\d*)s\)', msg)
+                if timeout_match:
+                    timeout_val = timeout_match.group(1)
+                    return f"Search stopped: Time limit reached (max {timeout_val}s)."
+                else:
+                    timeout_val = iterator.settings.get('iteration_timeout', iterator.settings.get('timeout', 300))
+                    return f"Search stopped: Time limit reached (max {timeout_val}s)."
+            elif "consecutive invalid" in msg or "consecutive failed" in msg:
+                max_attempts = iterator.settings.get('max_invalid_attempts', 20)
+                return f"Search stopped: {max_attempts} consecutive attempts found only isomorphic models."
+            elif "Insufficient progress" in msg:
+                return "Search stopped: Too many checks with insufficient progress."
+        
+        # Default message if no specific reason found
+        return f"Search ended after finding {found_count} of {requested_count} requested models."
         
     def process_iterations(self, example_name, example_case, theory_name, semantic_theory):
         """Process multiple iterations of model checking for a given example.
@@ -823,6 +1122,78 @@ class BuildModule:
         # Forward to the new process_example method which handles iteration in a better way
         return self.process_example(example_name, example_case, theory_name, semantic_theory)
 
+    def _capture_and_save_output(self, example, example_name, theory_name, model_num=None):
+        """Capture and save model output if save_output is enabled.
+        
+        Args:
+            example: The BuildExample instance
+            example_name: Name of the example
+            theory_name: Name of the theory
+            model_num: Optional model number for iterations
+        """
+        if not self.output_manager.should_save():
+            # Just print normally if not saving
+            example.print_model(example_name, theory_name)
+            return
+            
+        # Import necessary components
+        from model_checker.output import ModelDataCollector, MarkdownFormatter, ANSIToMarkdown
+        import io
+        import sys
+        
+        # Capture the output
+        captured_output = io.StringIO()
+        old_stdout = sys.stdout
+        sys.stdout = captured_output
+        
+        try:
+            # Print the model to our capture buffer
+            example.print_model(example_name, theory_name, output=captured_output)
+            raw_output = captured_output.getvalue()
+        finally:
+            sys.stdout = old_stdout
+            
+        # Also print to console so user sees output
+        print(raw_output, end='')
+        
+        # Convert ANSI colors if present
+        converter = ANSIToMarkdown()
+        converted_output = converter.convert(raw_output)
+        
+        # Collect model data
+        collector = ModelDataCollector()
+        model_data = collector.collect_model_data(
+            example.model_structure,
+            example_name,
+            theory_name
+        )
+        
+        # If this is part of an iteration, update the example name
+        if model_num is not None:
+            display_name = f"{example_name}_model{model_num}"
+        else:
+            display_name = example_name
+            
+        # Format the output
+        formatter = MarkdownFormatter(use_colors=True)
+        formatted_output = formatter.format_example(model_data, converted_output)
+        
+        # Handle interactive vs batch save
+        if self.interactive_manager and self.interactive_manager.is_interactive():
+            # Check if model found
+            if example.model_structure.z3_model_status:
+                # Prompt to save this model
+                if self.interactive_manager.prompt_save_model(example_name):
+                    # Get model number
+                    model_number = model_num or self.interactive_manager.get_next_model_number(example_name)
+                    # Save interactively
+                    self.output_manager.save_model_interactive(
+                        example_name, model_data, formatted_output, model_number
+                    )
+        else:
+            # Batch mode - save normally
+            self.output_manager.save_example(display_name, model_data, formatted_output)
+    
     def run_examples(self):
         """Process and execute each example case with all semantic theories.
         
@@ -838,30 +1209,59 @@ class BuildModule:
         # For each example, create a completely isolated Z3 environment
         # This ensures no state leakage between examples, solving the timeout issues
         # that can occur when running multiple examples in sequence
-        for example_name, example_case in self.example_range.items():
-            # Force garbage collection to clean up any lingering Z3 objects
-            gc.collect()
-            
-            # Reset Z3 context to create a fresh environment for this example
-            # This is the critical fix for ensuring proper Z3 state isolation
-            # Each example gets its own fresh Z3 context, preventing any state leakage
-            import z3
-            if hasattr(z3, '_main_ctx'):
-                z3._main_ctx = None
-            
-            # Force another garbage collection to ensure clean state
-            gc.collect()
-            
-            # Run the system in a clean state
-            for theory_name, semantic_theory in self.semantic_theories.items():
-                # Make setting reset for each semantic_theory
-                example_copy = list(example_case)
-                example_copy[2] = example_case[2].copy()
+        try:
+            for example_name, example_case in self.example_range.items():
+                # Force garbage collection to clean up any lingering Z3 objects
+                gc.collect()
                 
-                # Process the example with our new unified approach
-                # This handles both single models and iterations consistently
-                try:
-                    self.process_example(example_name, example_copy, theory_name, semantic_theory)
-                finally:
-                    # Force cleanup after each example to prevent state leaks
-                    gc.collect()
+                # Reset Z3 context to create a fresh environment for this example
+                # This is the critical fix for ensuring proper Z3 state isolation
+                # Each example gets its own fresh Z3 context, preventing any state leakage
+                import z3
+                if hasattr(z3, '_main_ctx'):
+                    z3._main_ctx = None
+                
+                # Force another garbage collection to ensure clean state
+                gc.collect()
+                
+                # Run the system in a clean state
+                for theory_name, semantic_theory in self.semantic_theories.items():
+                    # Make setting reset for each semantic_theory
+                    example_copy = list(example_case)
+                    example_copy[2] = example_case[2].copy()
+                    
+                    # Process the example with our new unified approach
+                    # This handles both single models and iterations consistently
+                    try:
+                        self.process_example(example_name, example_copy, theory_name, semantic_theory)
+                    finally:
+                        # Force cleanup after each example to prevent state leaks
+                        gc.collect()
+                        
+        except KeyboardInterrupt:
+            print("\n\nExecution interrupted by user.")
+            # Still finalize if we saved any output
+            if self.output_manager.should_save() and self.output_manager.output_dir is not None:
+                self.output_manager.finalize()
+                import os
+                print(f"\nPartial output saved to: {os.path.abspath(self.output_manager.output_dir)}")
+            sys.exit(1)
+                    
+        # Finalize output saving if enabled
+        if self.output_manager.should_save():
+            self.output_manager.finalize()
+            
+            # Only print path if output was actually saved
+            if self.output_manager.output_dir is not None:
+                # Get full path for display
+                import os
+                full_path = os.path.abspath(self.output_manager.output_dir)
+                
+                # Prompt for directory change
+                if self.interactive_manager:
+                    self.interactive_manager.prompt_change_directory(full_path)
+                else:
+                    # No interactive manager - show instructions directly
+                    print(f"\nOutput saved to: {full_path}")
+                    print(f"To change to output directory, run:")
+                    print(f"  cd {full_path}")
