@@ -71,7 +71,6 @@ Settings Options:
 - disjoint: Whether to enforce disjoint valuations
 - max_time: Maximum computation time in seconds
 - expectation: Whether the example is expected to be valid
-- iterate: Number of iterations for modal operators
 
 Notes:
 ------
@@ -143,11 +142,11 @@ bimodal_theory = {
 EX_CM_1_premises = ['(A \\vee B)']
 EX_CM_1_conclusions = ['(A \\wedge B)']
 EX_CM_1_settings = {
-    'N' : 1,
+    'N' : 2,
     'M' : 1,
     'contingent' : False,
     'disjoint' : False,
-    'max_time' : 2,
+    'max_time' : 10,
     'expectation' : True,
 }
 EX_CM_1_example = [
@@ -167,11 +166,10 @@ MD_CM_1_premises = ['\\Box (A \\vee B)']
 MD_CM_1_conclusions = ['\\Box A', '\\Box B']
 MD_CM_1_settings = {
     'N' : 1,
-    'M' : 1,  # Changed from 1 to 2 to match TN_CM_1
+    'M' : 1,
     'contingent' : False,
     'disjoint' : False,
-    'max_time' : 5,  # Increased from 2 to 5 to match TN_CM_1
-    'iterate' : 1,
+    'max_time' : 5,
     'expectation' : True,
 }
 MD_CM_1_example = [
@@ -571,15 +569,8 @@ BM_TH_5_example = [
 ### DEFINE EXAMPLES AND THEORIES TO COMPUTE ###
 ###############################################
 
-# NOTE: at least one theory is required, multiple are permitted for comparison
-semantic_theories = {
-    "Brast-McKie" : bimodal_theory,
-    # additional theories will require their own translation dictionaries
-}
-
-test_example_range = {
-    ### COUNTERMODELS ###
-
+# Organize examples by category
+countermodel_examples = {
     # Extensional Countermodels
     "EX_CM_1" : EX_CM_1_example,
     
@@ -600,9 +591,9 @@ test_example_range = {
     "BM_CM_2" : BM_CM_2_example,
     "BM_CM_3" : BM_CM_3_example,
     "BM_CM_4" : BM_CM_4_example,
+}
 
-    ### THEOREMS ###
-
+theorem_examples = {
     # Extensional Theorems
     "EX_TH_1" : EX_TH_1_example,
 
@@ -620,6 +611,15 @@ test_example_range = {
     "BM_TH_4" : BM_TH_4_example,
 }
 
+# Combine for unit_tests (used by test framework)
+unit_tests = {**countermodel_examples, **theorem_examples}
+
+# NOTE: at least one theory is required, multiple are permitted for comparison
+semantic_theories = {
+    "Bimodal" : bimodal_theory,
+    # additional theories will require their own translation dictionaries
+}
+
 # NOTE: at least one example is required, multiple are permitted for comparison
 example_range = {
 
@@ -629,22 +629,22 @@ example_range = {
     "EX_CM_1" : EX_CM_1_example,
     
     # Modal Countermodels
-    "MD_CM_1" : MD_CM_1_example,
-    "MD_CM_2" : MD_CM_2_example,
-    "MD_CM_3" : MD_CM_3_example,
-    "MD_CM_4" : MD_CM_4_example,
-    "MD_CM_5" : MD_CM_5_example,
-    "MD_CM_6" : MD_CM_6_example,
+    # "MD_CM_1" : MD_CM_1_example,
+    # "MD_CM_2" : MD_CM_2_example,
+    # "MD_CM_3" : MD_CM_3_example,
+    # "MD_CM_4" : MD_CM_4_example,
+    # "MD_CM_5" : MD_CM_5_example,
+    # "MD_CM_6" : MD_CM_6_example,
 
     # Tense Countermodels
-    "TN_CM_1" : TN_CM_1_example,
-    "TN_CM_2" : TN_CM_2_example,
+    # "TN_CM_1" : TN_CM_1_example,
+    # "TN_CM_2" : TN_CM_2_example,
     
     # Bimodal Countermodel
-    "BM_CM_1" : BM_CM_1_example,
-    "BM_CM_2" : BM_CM_2_example,
-    "BM_CM_3" : BM_CM_3_example,
-    "BM_CM_4" : BM_CM_4_example,
+    # "BM_CM_1" : BM_CM_1_example,
+    # "BM_CM_2" : BM_CM_2_example,
+    # "BM_CM_3" : BM_CM_3_example,
+    # "BM_CM_4" : BM_CM_4_example,
 
     ### THEOREMS ###
 
