@@ -56,7 +56,6 @@ from .semantic import WitnessStructure
 # NOTE: The default theory has been removed.
 # For comparison with standard bilateral semantics, use the logos theory instead.
 
-# Import logos theory components for comparison
 from model_checker.theory_lib.logos import (
     LogosSemantics,
     LogosProposition,
@@ -73,16 +72,16 @@ from model_checker.theory_lib.logos import (
 EX_CM_1_premises = []
 EX_CM_1_conclusions = []
 EX_CM_1_settings = {
-    'N': 2,
+    'N' : 2,
     'possible': False,
-    'contingent': False,
-    'non_empty': False,
-    'non_null': False,
-    'disjoint': False,
+    'contingent' : False,
+    'non_empty' : False,
+    'non_null' : False,
+    'disjoint' : False,
     'fusion_closure': False,
-    'max_time': 2,
-    'iterate': 1,
-    'expectation': True,
+    'max_time' : 2,
+    'iterate' : 1,
+    'expectation' : True,
 }
 EX_CM_1_example = [
     EX_CM_1_premises,
@@ -94,16 +93,16 @@ EX_CM_1_example = [
 EX_CM_2_premises = []
 EX_CM_2_conclusions = []
 EX_CM_2_settings = {
-    'N': 3,
+    'N' : 3,
     'possible': False,
-    'contingent': False,
-    'non_empty': False,
-    'non_null': False,
-    'disjoint': False,
+    'contingent' : False,
+    'non_empty' : False,
+    'non_null' : False,
+    'disjoint' : False,
     'fusion_closure': False,
-    'max_time': 10,
-    'iterate': 1,
-    'expectation': True,
+    'max_time' : 10,
+    'iterate' : 1,
+    'expectation' : True,
 }
 EX_CM_2_example = [
     EX_CM_2_premises,
@@ -115,16 +114,16 @@ EX_CM_2_example = [
 EX_CM_3_premises = []
 EX_CM_3_conclusions = []
 EX_CM_3_settings = {
-    'N': 3,
+    'N' : 3,
     'possible': False,
-    'contingent': False,
-    'non_empty': False,
-    'non_null': False,
-    'disjoint': False,
+    'contingent' : False,
+    'non_empty' : False,
+    'non_null' : False,
+    'disjoint' : False,
     'fusion_closure': False,
-    'max_time': 5,
-    'iterate': 1,
-    'expectation': True,
+    'max_time' : 5,
+    'iterate' : 1,
+    'expectation' : True,
 }
 EX_CM_3_example = [
     EX_CM_3_premises,
@@ -136,16 +135,16 @@ EX_CM_3_example = [
 EX_CM_4_premises = ['\\neg A']
 EX_CM_4_conclusions = ['A']
 EX_CM_4_settings = {
-    'N': 3,
+    'N' : 3,
     'possible': False,
-    'contingent': True,
-    'non_empty': True,
-    'non_null': True,
-    'disjoint': False,
+    'contingent' : True,
+    'non_empty' : True,
+    'non_null' : True,
+    'disjoint' : False,
     'fusion_closure': False,
-    'max_time': 5,
-    'iterate': 1,
-    'expectation': True,
+    'max_time' : 5,
+    'iterate' : 1,
+    'expectation' : True,
 }
 EX_CM_4_example = [
     EX_CM_4_premises,
@@ -157,16 +156,16 @@ EX_CM_4_example = [
 EX_CM_5_premises = ['A']
 EX_CM_5_conclusions = ['\\neg A']
 EX_CM_5_settings = {
-    'N': 3,
+    'N' : 3,
     'possible': False,
-    'contingent': True,
-    'non_empty': True,
-    'non_null': True,
-    'disjoint': False,
+    'contingent' : True,
+    'non_empty' : True,
+    'non_null' : True,
+    'disjoint' : False,
     'fusion_closure': False,
-    'max_time': 5,
-    'iterate': 1,
-    'expectation': True,
+    'max_time' : 5,
+    'iterate' : 1,
+    'expectation' : True,
 }
 EX_CM_5_example = [
     EX_CM_5_premises,
@@ -178,16 +177,16 @@ EX_CM_5_example = [
 EX_CM_6_premises = ['\\neg \\neg A']
 EX_CM_6_conclusions = ['A']
 EX_CM_6_settings = {
-    'N': 3,
+    'N' : 3,
     'possible': False,
-    'contingent': True,
-    'non_empty': True,
-    'non_null': True,
-    'disjoint': False,
+    'contingent' : True,
+    'non_empty' : True,
+    'non_null' : True,
+    'disjoint' : False,
     'fusion_closure': False,
-    'max_time': 5,
-    'iterate': 1,
-    'expectation': True,
+    'max_time' : 5,
+    'iterate' : 2,
+    'expectation' : True,
 }
 EX_CM_6_example = [
     EX_CM_6_premises,
@@ -199,16 +198,16 @@ EX_CM_6_example = [
 EX_CM_7_premises = ['A']
 EX_CM_7_conclusions = ['\\neg \\neg A']
 EX_CM_7_settings = {
-    'N': 3,
+    'N' : 3,
     'possible': False,
-    'contingent': True,
-    'non_empty': True,
-    'non_null': True,
-    'disjoint': False,
+    'contingent' : True,
+    'non_empty' : True,
+    'non_null' : True,
+    'disjoint' : False,
     'fusion_closure': False,
-    'max_time': 5,
-    'iterate': 1,
-    'expectation': True,
+    'max_time' : 5,
+    'iterate' : 1,
+    'expectation' : True,
 }
 EX_CM_7_example = [
     EX_CM_7_premises,
@@ -220,15 +219,15 @@ EX_CM_7_example = [
 EX_CM_8_premises = ['\\neg \\neg \\neg A']
 EX_CM_8_conclusions = ['\\neg A']
 EX_CM_8_settings = {
-    'N': 3,
+    'N' : 3,
     'possible': False,
-    'contingent': False,
-    'non_empty': False,
-    'non_null': False,
-    'disjoint': False,
+    'contingent' : False,
+    'non_empty' : False,
+    'non_null' : False,
+    'disjoint' : False,
     'fusion_closure': False,
-    'max_time': 20,
-    'expectation': True,
+    'max_time' : 20,
+    'expectation' : True,
 }
 EX_CM_8_example = [
     EX_CM_8_premises,
@@ -240,15 +239,15 @@ EX_CM_8_example = [
 EX_CM_9_premises = ['\\neg \\neg \\neg \\neg A']
 EX_CM_9_conclusions = ['A']
 EX_CM_9_settings = {
-    'N': 3,
+    'N' : 3,
     'possible': False,
-    'contingent': False,
-    'non_empty': False,
-    'non_null': False,
-    'disjoint': False,
+    'contingent' : False,
+    'non_empty' : False,
+    'non_null' : False,
+    'disjoint' : False,
     'fusion_closure': False,
-    'max_time': 20,
-    'expectation': True,
+    'max_time' : 20,
+    'expectation' : True,
 }
 EX_CM_9_example = [
     EX_CM_9_premises,
@@ -260,15 +259,16 @@ EX_CM_9_example = [
 EX_CM_10_premises = ['(\\neg A \\vee \\neg B)']
 EX_CM_10_conclusions = ['\\neg (A \\wedge B)']
 EX_CM_10_settings = {
-    'N': 3,
+    'N' : 3,
     'possible': False,
-    'contingent': False,
-    'non_empty': False,
-    'non_null': False,
-    'disjoint': False,
+    'contingent' : False,
+    'non_empty' : False,
+    'non_null' : False,
+    'disjoint' : False,
     'fusion_closure': False,
-    'max_time': 5,
-    'expectation': True,
+    'max_time' : 5,
+    'iterate' : 2,
+    'expectation' : True,
 }
 EX_CM_10_example = [
     EX_CM_10_premises,
@@ -280,15 +280,15 @@ EX_CM_10_example = [
 EX_CM_11_premises = ['\\neg (A \\wedge B)']
 EX_CM_11_conclusions = ['(\\neg A \\vee \\neg B)']
 EX_CM_11_settings = {
-    'N': 3,
+    'N' : 3,
     'possible': False,
-    'contingent': False,
-    'non_empty': False,
-    'non_null': False,
-    'disjoint': False,
+    'contingent' : False,
+    'non_empty' : False,
+    'non_null' : False,
+    'disjoint' : False,
     'fusion_closure': False,
-    'max_time': 5,
-    'expectation': True,
+    'max_time' : 5,
+    'expectation' : True,
 }
 EX_CM_11_example = [
     EX_CM_11_premises,
@@ -300,15 +300,15 @@ EX_CM_11_example = [
 EX_CM_12_premises = ['\\neg (A \\vee B)']
 EX_CM_12_conclusions = ['(\\neg A \\wedge \\neg B)']
 EX_CM_12_settings = {
-    'N': 3,
+    'N' : 3,
     'possible': False,
-    'contingent': False,
-    'non_empty': False,
-    'non_null': False,
-    'disjoint': False,
+    'contingent' : False,
+    'non_empty' : False,
+    'non_null' : False,
+    'disjoint' : False,
     'fusion_closure': False,
-    'max_time': 5,
-    'expectation': True,
+    'max_time' : 5,
+    'expectation' : True,
 }
 EX_CM_12_example = [
     EX_CM_12_premises,
@@ -320,15 +320,15 @@ EX_CM_12_example = [
 EX_CM_13_premises = ['(\\neg A \\wedge \\neg B)']
 EX_CM_13_conclusions = ['\\neg (A \\vee B)']
 EX_CM_13_settings = {
-    'N': 3,
+    'N' : 3,
     'possible': False,
-    'contingent': False,
-    'non_empty': False,
-    'non_null': False,
-    'disjoint': False,
+    'contingent' : False,
+    'non_empty' : False,
+    'non_null' : False,
+    'disjoint' : False,
     'fusion_closure': False,
-    'max_time': 5,
-    'expectation': True,
+    'max_time' : 5,
+    'expectation' : True,
 }
 EX_CM_13_example = [
     EX_CM_13_premises,
@@ -340,16 +340,16 @@ EX_CM_13_example = [
 EX_CM_14_premises = []
 EX_CM_14_conclusions = ['(\\neg \\neg A \\equiv A)']
 EX_CM_14_settings = {
-    'N': 3,
+    'N' : 3,
     'possible': False,
-    'contingent': True,
-    'non_empty': True,
-    'non_null': True,
-    'disjoint': False,
+    'contingent' : True,
+    'non_empty' : True,
+    'non_null' : True,
+    'disjoint' : False,
     'fusion_closure': False,
-    'max_time': 10,
-    'iterate': 1,
-    'expectation': True,
+    'max_time' : 10,
+    'iterate' : 1,
+    'expectation' : True,
 }
 EX_CM_14_example = [
     EX_CM_14_premises,
@@ -361,16 +361,16 @@ EX_CM_14_example = [
 EX_CM_15_premises = []
 EX_CM_15_conclusions = ['(\\neg \\neg \\neg A \\equiv \\neg A)']
 EX_CM_15_settings = {
-    'N': 3,
+    'N' : 3,
     'possible': False,
-    'contingent': True,
-    'non_empty': True,
-    'non_null': True,
-    'disjoint': False,
+    'contingent' : True,
+    'non_empty' : True,
+    'non_null' : True,
+    'disjoint' : False,
     'fusion_closure': False,
-    'max_time': 10,
-    'iterate': 1,
-    'expectation': True,
+    'max_time' : 10,
+    'iterate' : 1,
+    'expectation' : True,
 }
 EX_CM_15_example = [
     EX_CM_15_premises,
@@ -382,16 +382,16 @@ EX_CM_15_example = [
 EX_CM_16_premises = []
 EX_CM_16_conclusions = ['(\\neg (A \\wedge B) \\equiv (\\neg A \\vee \\neg B))']
 EX_CM_16_settings = {
-    'N': 3,
+    'N' : 3,
     'possible': False,
-    'contingent': True,
-    'non_empty': True,
-    'non_null': True,
-    'disjoint': False,
+    'contingent' : True,
+    'non_empty' : True,
+    'non_null' : True,
+    'disjoint' : False,
     'fusion_closure': False,
-    'max_time': 10,
-    'iterate': 1,
-    'expectation': True,
+    'max_time' : 10,
+    'iterate' : 1,
+    'expectation' : True,
 }
 EX_CM_16_example = [
     EX_CM_16_premises,
@@ -403,16 +403,16 @@ EX_CM_16_example = [
 EX_CM_17_premises = []
 EX_CM_17_conclusions = ['(\\neg (A \\vee B) \\equiv (\\neg A \\wedge \\neg B))']
 EX_CM_17_settings = {
-    'N': 3,
+    'N' : 3,
     'possible': False,
-    'contingent': True,
-    'non_empty': True,
-    'non_null': True,
-    'disjoint': False,
+    'contingent' : True,
+    'non_empty' : True,
+    'non_null' : True,
+    'disjoint' : False,
     'fusion_closure': False,
-    'max_time': 10,
-    'iterate': 1,
-    'expectation': True,
+    'max_time' : 10,
+    'iterate' : 1,
+    'expectation' : True,
 }
 EX_CM_17_example = [
     EX_CM_17_premises,
@@ -424,16 +424,16 @@ EX_CM_17_example = [
 EX_CM_18_premises = []
 EX_CM_18_conclusions = ['((A \\vee (B \\wedge C)) \\equiv ((A \\vee B) \\wedge (A \\vee C)))']
 EX_CM_18_settings = {
-    'N': 3,
+    'N' : 3,
     'possible': False,
-    'contingent': True,
-    'non_empty': True,
-    'non_null': True,
-    'disjoint': False,
+    'contingent' : True,
+    'non_empty' : True,
+    'non_null' : True,
+    'disjoint' : False,
     'fusion_closure': False,
-    'max_time': 10,
-    'iterate': 1,
-    'expectation': True,
+    'max_time' : 10,
+    'iterate' : 1,
+    'expectation' : True,
 }
 EX_CM_18_example = [
     EX_CM_18_premises,
@@ -445,15 +445,15 @@ EX_CM_18_example = [
 EX_CM_19_premises = []
 EX_CM_19_conclusions = ['((\\neg (A \\vee B) \\equiv (\\neg A \\wedge \\neg B)) \\wedge (\\neg (A \\wedge B) \\equiv (\\neg A \\vee \\neg B)))']
 EX_CM_19_settings = {
-    'N': 4,
+    'N' : 4,
     'possible': False,
-    'contingent': True,
-    'non_empty': True,
-    'non_null': True,
-    'disjoint': False,
+    'contingent' : True,
+    'non_empty' : True,
+    'non_null' : True,
+    'disjoint' : False,
     'fusion_closure': False,
-    'max_time': 10,
-    'expectation': True,
+    'max_time' : 10,
+    'expectation' : True,
 }
 EX_CM_19_example = [
     EX_CM_19_premises,
@@ -465,16 +465,16 @@ EX_CM_19_example = [
 EX_CM_20_premises = []
 EX_CM_20_conclusions = ['(\\neg (A \\vee B) \\equiv (\\neg A \\wedge \\neg B))']
 EX_CM_20_settings = {
-    'N': 3,
+    'N' : 3,
     'possible': False,
-    'contingent': True,
-    'non_empty': True,
-    'non_null': True,
-    'disjoint': False,
+    'contingent' : True,
+    'non_empty' : True,
+    'non_null' : True,
+    'disjoint' : False,
     'fusion_closure': False,
-    'max_time': 10,
-    'iterate': 1,
-    'expectation': True,
+    'max_time' : 10,
+    'iterate' : 1,
+    'expectation' : True,
 }
 EX_CM_20_example = [
     EX_CM_20_premises,
@@ -486,16 +486,16 @@ EX_CM_20_example = [
 EX_CM_21_premises = ['A']
 EX_CM_21_conclusions = ['B']
 EX_CM_21_settings = {
-    'N': 3,
+    'N' : 3,
     'possible': False,
-    'contingent': False,
-    'non_empty': False,
-    'non_null': False,
-    'disjoint': False,
+    'contingent' : False,
+    'non_empty' : False,
+    'non_null' : False,
+    'disjoint' : False,
     'fusion_closure': False,
-    'max_time': 5,
-    'iterate': 1,
-    'expectation': True,
+    'max_time' : 5,
+    'iterate' : 1,
+    'expectation' : True,
 }
 EX_CM_21_example = [
     EX_CM_21_premises,
@@ -507,16 +507,16 @@ EX_CM_21_example = [
 EX_CM_22_premises = ['(A \\wedge (B \\vee C))']
 EX_CM_22_conclusions = ['((A \\wedge B) \\vee (A \\wedge D))']
 EX_CM_22_settings = {
-    'N': 3,
+    'N' : 3,
     'possible': False,
-    'contingent': False,
-    'non_empty': False,
-    'non_null': False,
-    'disjoint': False,
+    'contingent' : False,
+    'non_empty' : False,
+    'non_null' : False,
+    'disjoint' : False,
     'fusion_closure': False,
-    'max_time': 5,
-    'iterate': 1,
-    'expectation': True,
+    'max_time' : 5,
+    'iterate' : 1,
+    'expectation' : True,
 }
 EX_CM_22_example = [
     EX_CM_22_premises,
@@ -534,15 +534,15 @@ EX_CM_22_example = [
 EX_TH_1_premises = ['A']
 EX_TH_1_conclusions = ['A']
 EX_TH_1_settings = {
-    'N': 2,
+    'N' : 2,
     'possible': False,
-    'contingent': False,
-    'non_empty': False,
-    'non_null': False,
-    'disjoint': False,
+    'contingent' : False,
+    'non_empty' : False,
+    'non_null' : False,
+    'disjoint' : False,
     'fusion_closure': False,
-    'max_time': 2,
-    'expectation': False,
+    'max_time' : 2,
+    'expectation' : False,
 }
 EX_TH_1_example = [
     EX_TH_1_premises,
@@ -554,16 +554,16 @@ EX_TH_1_example = [
 EX_TH_2_premises = ['(A \\vee B)', '\\neg A']
 EX_TH_2_conclusions = ['B']
 EX_TH_2_settings = {
-    'N': 3,
+    'N' : 3,
     'possible': False,
-    'contingent': False,
-    'non_empty': False,
-    'non_null': False,
-    'disjoint': False,
+    'contingent' : False,
+    'non_empty' : False,
+    'non_null' : False,
+    'disjoint' : False,
     'fusion_closure': False,
-    'max_time': 5,
-    'iterate': 1,
-    'expectation': False,
+    'max_time' : 5,
+    'iterate' : 2,
+    'expectation' : False,
 }
 EX_TH_2_example = [
     EX_TH_2_premises,
@@ -575,15 +575,15 @@ EX_TH_2_example = [
 EX_TH_3_premises = ['(A \\wedge (B \\vee C))']
 EX_TH_3_conclusions = ['((A \\wedge B) \\vee (A \\wedge C))']
 EX_TH_3_settings = {
-    'N': 3,
+    'N' : 3,
     'possible': False,
-    'contingent': False,
-    'non_empty': False,
-    'non_null': False,
-    'disjoint': False,
+    'contingent' : False,
+    'non_empty' : False,
+    'non_null' : False,
+    'disjoint' : False,
     'fusion_closure': False,
-    'max_time': 5,
-    'expectation': False,
+    'max_time' : 5,
+    'expectation' : False,
 }
 EX_TH_3_example = [
     EX_TH_3_premises,
@@ -595,15 +595,15 @@ EX_TH_3_example = [
 EX_TH_4_premises = ['((A \\wedge B) \\vee (A \\wedge C))']
 EX_TH_4_conclusions = ['(A \\wedge (B \\vee C))']
 EX_TH_4_settings = {
-    'N': 3,
+    'N' : 3,
     'possible': False,
-    'contingent': False,
-    'non_empty': False,
-    'non_null': False,
-    'disjoint': False,
+    'contingent' : False,
+    'non_empty' : False,
+    'non_null' : False,
+    'disjoint' : False,
     'fusion_closure': False,
-    'max_time': 5,
-    'expectation': False,
+    'max_time' : 5,
+    'expectation' : False,
 }
 EX_TH_4_example = [
     EX_TH_4_premises,
@@ -615,15 +615,15 @@ EX_TH_4_example = [
 EX_TH_5_premises = ['(A \\vee (B \\wedge C))']
 EX_TH_5_conclusions = ['((A \\vee B) \\wedge (A \\vee C))']
 EX_TH_5_settings = {
-    'N': 3,
+    'N' : 3,
     'possible': False,
-    'contingent': False,
-    'non_empty': False,
-    'non_null': False,
-    'disjoint': False,
+    'contingent' : False,
+    'non_empty' : False,
+    'non_null' : False,
+    'disjoint' : False,
     'fusion_closure': False,
-    'max_time': 5,
-    'expectation': False,
+    'max_time' : 5,
+    'expectation' : False,
 }
 EX_TH_5_example = [
     EX_TH_5_premises,
@@ -635,15 +635,15 @@ EX_TH_5_example = [
 EX_TH_6_premises = ['((A \\vee B) \\wedge (A \\vee C))']
 EX_TH_6_conclusions = ['(A \\vee (B \\wedge C))']
 EX_TH_6_settings = {
-    'N': 3,
+    'N' : 3,
     'possible': False,
-    'contingent': False,
-    'non_empty': False,
-    'non_null': False,
-    'disjoint': False,
+    'contingent' : False,
+    'non_empty' : False,
+    'non_null' : False,
+    'disjoint' : False,
     'fusion_closure': False,
-    'max_time': 5,
-    'expectation': False,
+    'max_time' : 5,
+    'expectation' : False,
 }
 EX_TH_6_example = [
     EX_TH_6_premises,
@@ -655,15 +655,15 @@ EX_TH_6_example = [
 EX_TH_7_premises = ['(A \\wedge (A \\vee B))']
 EX_TH_7_conclusions = ['A']
 EX_TH_7_settings = {
-    'N': 3,
+    'N' : 3,
     'possible': False,
-    'contingent': False,
-    'non_empty': False,
-    'non_null': False,
-    'disjoint': False,
+    'contingent' : False,
+    'non_empty' : False,
+    'non_null' : False,
+    'disjoint' : False,
     'fusion_closure': False,
-    'max_time': 5,
-    'expectation': False,
+    'max_time' : 5,
+    'expectation' : False,
 }
 EX_TH_7_example = [
     EX_TH_7_premises,
@@ -675,15 +675,15 @@ EX_TH_7_example = [
 EX_TH_8_premises = ['A']
 EX_TH_8_conclusions = ['(A \\wedge (A \\vee B))']
 EX_TH_8_settings = {
-    'N': 3,
+    'N' : 3,
     'possible': False,
-    'contingent': False,
-    'non_empty': False,
-    'non_null': False,
-    'disjoint': False,
+    'contingent' : False,
+    'non_empty' : False,
+    'non_null' : False,
+    'disjoint' : False,
     'fusion_closure': False,
-    'max_time': 5,
-    'expectation': False,
+    'max_time' : 5,
+    'expectation' : False,
 }
 EX_TH_8_example = [
     EX_TH_8_premises,
@@ -695,15 +695,15 @@ EX_TH_8_example = [
 EX_TH_9_premises = ['(A \\vee (A \\wedge B))']
 EX_TH_9_conclusions = ['A']
 EX_TH_9_settings = {
-    'N': 3,
+    'N' : 3,
     'possible': False,
-    'contingent': False,
-    'non_empty': False,
-    'non_null': False,
-    'disjoint': False,
+    'contingent' : False,
+    'non_empty' : False,
+    'non_null' : False,
+    'disjoint' : False,
     'fusion_closure': False,
-    'max_time': 5,
-    'expectation': False,
+    'max_time' : 5,
+    'expectation' : False,
 }
 EX_TH_9_example = [
     EX_TH_9_premises,
@@ -715,15 +715,15 @@ EX_TH_9_example = [
 EX_TH_10_premises = ['A']
 EX_TH_10_conclusions = ['(A \\vee (A \\wedge B))']
 EX_TH_10_settings = {
-    'N': 3,
+    'N' : 3,
     'possible': False,
-    'contingent': False,
-    'non_empty': False,
-    'non_null': False,
-    'disjoint': False,
+    'contingent' : False,
+    'non_empty' : False,
+    'non_null' : False,
+    'disjoint' : False,
     'fusion_closure': False,
-    'max_time': 5,
-    'expectation': False,
+    'max_time' : 5,
+    'expectation' : False,
 }
 EX_TH_10_example = [
     EX_TH_10_premises,
@@ -735,15 +735,15 @@ EX_TH_10_example = [
 EX_TH_11_premises = ['((A \\wedge B) \\wedge C)']
 EX_TH_11_conclusions = ['(A \\wedge (B \\wedge C))']
 EX_TH_11_settings = {
-    'N': 3,
+    'N' : 3,
     'possible': False,
-    'contingent': False,
-    'non_empty': False,
-    'non_null': False,
-    'disjoint': False,
+    'contingent' : False,
+    'non_empty' : False,
+    'non_null' : False,
+    'disjoint' : False,
     'fusion_closure': False,
-    'max_time': 5,
-    'expectation': False,
+    'max_time' : 5,
+    'expectation' : False,
 }
 EX_TH_11_example = [
     EX_TH_11_premises,
@@ -755,15 +755,15 @@ EX_TH_11_example = [
 EX_TH_12_premises = ['(A \\wedge (B \\wedge C))']
 EX_TH_12_conclusions = ['((A \\wedge B) \\wedge C)']
 EX_TH_12_settings = {
-    'N': 3,
+    'N' : 3,
     'possible': False,
-    'contingent': False,
-    'non_empty': False,
-    'non_null': False,
-    'disjoint': False,
+    'contingent' : False,
+    'non_empty' : False,
+    'non_null' : False,
+    'disjoint' : False,
     'fusion_closure': False,
-    'max_time': 5,
-    'expectation': False,
+    'max_time' : 5,
+    'expectation' : False,
 }
 EX_TH_12_example = [
     EX_TH_12_premises,
@@ -775,15 +775,15 @@ EX_TH_12_example = [
 EX_TH_13_premises = ['((A \\vee B) \\vee C)']
 EX_TH_13_conclusions = ['(A \\vee (B \\vee C))']
 EX_TH_13_settings = {
-    'N': 3,
+    'N' : 3,
     'possible': False,
-    'contingent': False,
-    'non_empty': False,
-    'non_null': False,
-    'disjoint': False,
+    'contingent' : False,
+    'non_empty' : False,
+    'non_null' : False,
+    'disjoint' : False,
     'fusion_closure': False,
-    'max_time': 5,
-    'expectation': False,
+    'max_time' : 5,
+    'expectation' : False,
 }
 EX_TH_13_example = [
     EX_TH_13_premises,
@@ -795,15 +795,15 @@ EX_TH_13_example = [
 EX_TH_14_premises = ['(A \\vee (B \\vee C))']
 EX_TH_14_conclusions = ['((A \\vee B) \\vee C)']
 EX_TH_14_settings = {
-    'N': 3,
+    'N' : 3,
     'possible': False,
-    'contingent': False,
-    'non_empty': False,
-    'non_null': False,
-    'disjoint': False,
+    'contingent' : False,
+    'non_empty' : False,
+    'non_null' : False,
+    'disjoint' : False,
     'fusion_closure': False,
-    'max_time': 5,
-    'expectation': False,
+    'max_time' : 5,
+    'expectation' : False,
 }
 EX_TH_14_example = [
     EX_TH_14_premises,
@@ -815,16 +815,16 @@ EX_TH_14_example = [
 EX_TH_15_premises = []
 EX_TH_15_conclusions = ['((A \\wedge (B \\vee C)) \\equiv ((A \\wedge B) \\vee (A \\wedge C)))']
 EX_TH_15_settings = {
-    'N': 3,
+    'N' : 3,
     'possible': False,
-    'contingent': True,
-    'non_empty': True,
-    'non_null': True,
-    'disjoint': False,
+    'contingent' : True,
+    'non_empty' : True,
+    'non_null' : True,
+    'disjoint' : False,
     'fusion_closure': False,
-    'max_time': 10,
-    'iterate': 1,
-    'expectation': False,
+    'max_time' : 10,
+    'iterate' : 1,
+    'expectation' : False,
 }
 EX_TH_15_example = [
     EX_TH_15_premises,
@@ -836,15 +836,15 @@ EX_TH_15_example = [
 EX_TH_16_premises = ['(A \\wedge (B \\vee C))']
 EX_TH_16_conclusions = ['((A \\vee B) \\wedge (A \\vee B))']
 EX_TH_16_settings = {
-    'N': 3,
+    'N' : 3,
     'possible': False,
-    'contingent': False,
-    'non_empty': False,
-    'non_null': False,
-    'disjoint': False,
+    'contingent' : False,
+    'non_empty' : False,
+    'non_null' : False,
+    'disjoint' : False,
     'fusion_closure': False,
-    'max_time': 10,
-    'expectation': False,
+    'max_time' : 10,
+    'expectation' : False,
 }
 EX_TH_16_example = [
     EX_TH_16_premises,
@@ -854,8 +854,8 @@ EX_TH_16_example = [
 
 
 
-# Create collections for different exclusion example types
-exclusion_cm_examples = {
+# Organize examples by category
+countermodel_examples = {
     "EX_CM_1": EX_CM_1_example,    # EMPTY CASE FOR CHECKING FRAME CONSTRAINTS
     "EX_CM_2": EX_CM_2_example,    # GAPS CASE
     "EX_CM_3": EX_CM_3_example,    # NO GLUT CASE
@@ -880,7 +880,7 @@ exclusion_cm_examples = {
     "EX_CM_22": EX_CM_22_example,  # DISTRIBUTION TEST
 }
 
-exclusion_th_examples = {
+theorem_examples = {
     "EX_TH_1": EX_TH_1_example,    # ATOMIC THEOREM
     "EX_TH_2": EX_TH_2_example,    # DISJUNCTIVE SYLLOGISM
     "EX_TH_3": EX_TH_3_example,    # CONJUNCTION DISTRIBUTION LR
@@ -899,8 +899,8 @@ exclusion_th_examples = {
     "EX_TH_16": EX_TH_16_example,  # COMPLEX UNILATERAL FORMULA
 }
 
-# Combined collection of all exclusion examples
-unit_tests = {**exclusion_cm_examples, **exclusion_th_examples}
+# Combine for unit_tests (used by test framework)
+unit_tests = {**countermodel_examples, **theorem_examples}
 
 # Aliases for main dictionary (backward compatibility)
 test_example_range = unit_tests
@@ -965,13 +965,13 @@ example_range = {
     # # Bilateral negation examples (Problematic in static)
     # "EX_CM_4": EX_CM_4_example,    # NEGATION TO SENTENCE (FALSE PREMISE PROBLEM)
     # "EX_CM_5": EX_CM_5_example,    # SENTENCE TO NEGATION (FALSE PREMISE PROBLEM)
-    "EX_CM_6": EX_CM_6_example,    # DOUBLE NEGATION ELIMINATION (FALSE PREMISE PROBLEM)
+    # "EX_CM_6": EX_CM_6_example,    # DOUBLE NEGATION ELIMINATION (FALSE PREMISE PROBLEM)
     # "EX_CM_7": EX_CM_7_example,    # DOUBLE NEGATION INTRODUCTION (FALSE PREMISE PROBLEM)
     # "EX_CM_8": EX_CM_8_example,    # TRIPLE NEGATION ENTAILMENT (FALSE PREMISE PROBLEM)
     # "EX_CM_9": EX_CM_9_example,    # QUADRUPLE NEGATION ENTAILMENT (FALSE PREMISE PROBLEM)
     #
     # # DeMorgan's laws (Problematic in static)
-    # "EX_CM_10": EX_CM_10_example,  # CONJUNCTION DEMORGAN LR (FALSE PREMISE PROBLEM)
+    "EX_CM_10": EX_CM_10_example,  # CONJUNCTION DEMORGAN LR (FALSE PREMISE PROBLEM)
     # "EX_CM_11": EX_CM_11_example,  # CONJUNCTION DEMORGAN RL (FALSE PREMISE PROBLEM)
     # "EX_CM_12": EX_CM_12_example,  # DISJUNCTION DEMORGAN LR (FALSE PREMISE PROBLEM)
     # "EX_CM_13": EX_CM_13_example,  # DISJUNCTION DEMORGAN RL (FALSE PREMISE PROBLEM)
