@@ -15,8 +15,10 @@ import z3
 import sys
 import time
 from typing import List, Dict, Set, Optional, Tuple
-from model_checker import model
-from model_checker.model import ModelDefaults, SemanticDefaults, PropositionDefaults
+from model_checker.models.structure import ModelDefaults
+from model_checker.models.semantic import SemanticDefaults
+from model_checker.models.proposition import PropositionDefaults
+from model_checker.models.constraints import ModelConstraints
 from model_checker.utils import ForAll, Exists, bitvec_to_substates, pretty_set_print, int_to_binary
 from model_checker import syntactic
 # Integrated witness model and constraint generator classes
@@ -273,8 +275,6 @@ class WitnessSemantics(SemanticDefaults):
         'disjoint': False,
         'fusion_closure': False,
         'iterate': 1,
-        'iteration_timeout': 1.0,
-        'iteration_attempts': 5,
         'max_time': 1,
         'expectation': None,
     }
@@ -680,6 +680,69 @@ class WitnessSemantics(SemanticDefaults):
     def _conclusion_behavior_method(self, conclusion):
         """Conclusion must be false at main evaluation point."""
         return z3.Not(self.true_at(conclusion, self.main_point))
+    
+    def inject_z3_model_values(self, z3_model, original_semantics, model_constraints):
+        """Inject concrete Z3 values from iteration into model constraints.
+        
+        This method extracts values from a Z3 model and adds them as constraints
+        for the next iteration. It handles Exclusion-specific concepts: worlds,
+        possible states, verify, and excludes relations.
+        
+        Args:
+            z3_model: Z3 model containing concrete values from solver
+            original_semantics: Original semantics instance that created the Z3 functions
+            model_constraints: ModelConstraints instance to update with injected values
+        """
+        # Get number of states from model_constraints settings
+        num_states = 2 ** model_constraints.settings['N']
+        
+        # Inject world constraints
+        for state in range(num_states):
+            # Evaluate using original is_world function
+            is_world_val = z3_model.eval(original_semantics.is_world(state), model_completion=True)
+            # Add constraint using new is_world function
+            if z3.is_true(is_world_val):
+                model_constraints.all_constraints.append(self.is_world(state))
+            else:
+                model_constraints.all_constraints.append(z3.Not(self.is_world(state)))
+        
+        # Inject possible state constraints
+        for state in range(num_states):
+            # Evaluate using original possible function
+            is_possible_val = z3_model.eval(original_semantics.possible(state), model_completion=True)
+            # Add constraint using new possible function
+            if z3.is_true(is_possible_val):
+                model_constraints.all_constraints.append(self.possible(state))
+            else:
+                model_constraints.all_constraints.append(z3.Not(self.possible(state)))
+        
+        # Inject verify/excludes constraints for each sentence letter
+        for sentence_obj in model_constraints.syntax.sentence_letters:
+            atom = sentence_obj.sentence_letter
+            
+            # Inject verify constraints
+            for state in range(num_states):
+                # Evaluate using original verify function
+                verify_val = z3_model.eval(original_semantics.verify(state, atom), model_completion=True)
+                # Add constraint using new verify function
+                if z3.is_true(verify_val):
+                    model_constraints.all_constraints.append(self.verify(state, atom))
+                else:
+                    model_constraints.all_constraints.append(z3.Not(self.verify(state, atom)))
+        
+        # Inject excludes relation constraints (state to state relation)
+        for state1 in range(num_states):
+            for state2 in range(num_states):
+                # Evaluate using original excludes function
+                excludes_val = z3_model.eval(original_semantics.excludes(state1, state2), model_completion=True)
+                # Add constraint using new excludes function
+                if z3.is_true(excludes_val):
+                    model_constraints.all_constraints.append(self.excludes(state1, state2))
+                else:
+                    model_constraints.all_constraints.append(z3.Not(self.excludes(state1, state2)))
+        
+        # Note: Witness predicates are handled separately by the theory
+        # and don't need to be injected here
 
 
 class WitnessModelAdapter(ModelDefaults):
@@ -696,8 +759,6 @@ class WitnessModelAdapter(ModelDefaults):
         'disjoint': False,
         'fusion_closure': False,
         'iterate': 1,
-        'iteration_timeout': 1.0,
-        'iteration_attempts': 5,
         'max_time': 1,
         'expectation': None,
     }
@@ -729,12 +790,12 @@ class WitnessModelAdapter(ModelDefaults):
         return self.semantics.extended_compute_verifiers(sentence, model, eval_point)
 
 
-class WitnessStructure(model.ModelDefaults):
+class WitnessStructure(ModelDefaults):
     """Extended model structure for witness predicate semantics with full printing."""
     
     def __init__(self, model_constraints, combined_settings):
         """Initialize with proper constraint checking."""
-        if not isinstance(model_constraints, model.ModelConstraints):
+        if not isinstance(model_constraints, ModelConstraints):
             raise TypeError(
                 f"Expected model_constraints to be a ModelConstraints object, "
                 f"got {type(model_constraints)}."
@@ -818,12 +879,50 @@ class WitnessStructure(model.ModelDefaults):
         """Delegate to semantics for extended verification."""
         return self.semantics.extended_verify(state, sentence, eval_point)
 
+    def _evaluate_z3_boolean(self, z3_model, expression):
+        """Safely evaluate a Z3 boolean expression to a Python boolean.
+        
+        This method handles the case where Z3 returns symbolic expressions
+        instead of concrete boolean values, which can cause
+        "Symbolic expressions cannot be cast to concrete Boolean values" errors.
+        """
+        try:
+            result = z3_model.evaluate(expression, model_completion=True)
+            
+            if z3.is_bool(result):
+                if z3.is_true(result):
+                    return True
+                elif z3.is_false(result):
+                    return False
+                    
+            simplified = z3.simplify(result)
+            
+            if z3.is_true(simplified):
+                return True
+            elif z3.is_false(simplified):
+                return False
+            
+            if str(simplified) == "True":
+                return True
+            elif str(simplified) == "False":
+                return False
+                
+            try:
+                return z3.simplify(simplified == z3.BoolVal(True)) == z3.BoolVal(True)
+            except Exception:
+                # logger.warning(f"Could not evaluate Z3 boolean expression: {expression}, assuming False")
+                return False
+                
+        except Exception as e:
+            # logger.warning(f"Error evaluating Z3 boolean expression {expression}: {e}, assuming False")
+            return False
+    
     def find_verifying_states(self, sentence, eval_point):
         """Find states that verify the sentence at evaluation point."""
         result = set()
         for state in self.all_states:
             constraint = self.extended_verify(state, sentence, eval_point)
-            if z3.is_true(self.z3_model.evaluate(constraint)):
+            if self._evaluate_z3_boolean(self.z3_model, constraint):
                 result.add(state)
         return result
 
@@ -832,7 +931,7 @@ class WitnessStructure(model.ModelDefaults):
         result = set()
         for state in self.all_states:
             constraint = self.semantics.verify(state, atom)
-            if z3.is_true(self.z3_model.evaluate(constraint)):
+            if self._evaluate_z3_boolean(self.z3_model, constraint):
                 result.add(state)
         return result
 
@@ -843,7 +942,7 @@ class WitnessStructure(model.ModelDefaults):
             result[state_x] = set()
             for state_y in self.all_states:
                 constraint = self.semantics.excludes(state_x, state_y)
-                if z3.is_true(self.z3_model.evaluate(constraint)):
+                if self._evaluate_z3_boolean(self.z3_model, constraint):
                     result[state_x].add(state_y)
         return result
     
@@ -892,7 +991,8 @@ class WitnessStructure(model.ModelDefaults):
             if output is sys.__stdout__:
                 total_time = round(time.time() - self.start_time, 4) 
                 print(f"Total Run Time: {total_time} seconds\n", file=output)
-                print(f"{'='*40}", file=output)
+            # Always print closing separator for countermodels
+            print(f"\n{'='*40}", file=output)
             return
             
     def print_states(self, output=sys.__stdout__):
@@ -1149,6 +1249,229 @@ class WitnessStructure(model.ModelDefaults):
         return True
 
 
+    def extract_states(self):
+        """Extract categorized states for output.
+        
+        Exclusion distinguishes between worlds, possible states, and impossible states.
+        
+        Returns:
+            Dict with keys 'worlds', 'possible', 'impossible'
+        """
+        states = {"worlds": [], "possible": [], "impossible": []}
+        
+        if hasattr(self, 'all_world_bits') and self.all_world_bits:
+            for state in self.all_world_bits:
+                if hasattr(state, 'as_long'):
+                    states["worlds"].append(f"s{state.as_long()}")
+                else:
+                    states["worlds"].append(f"s{state}")
+        
+        if hasattr(self, 'all_possible_bits') and self.all_possible_bits:
+            for state in self.all_possible_bits:
+                # Only add if not already a world
+                if state not in (self.all_world_bits if hasattr(self, 'all_world_bits') else []):
+                    if hasattr(state, 'as_long'):
+                        states["possible"].append(f"s{state.as_long()}")
+                    else:
+                        states["possible"].append(f"s{state}")
+        
+        # For impossible states, check all states that aren't possible
+        if hasattr(self, 'all_bits') and self.all_bits:
+            possible_set = set(self.all_possible_bits) if hasattr(self, 'all_possible_bits') else set()
+            for state in self.all_bits:
+                if state not in possible_set and state != 0:  # 0 is usually the null state
+                    if hasattr(state, 'as_long'):
+                        states["impossible"].append(f"s{state.as_long()}")
+                    else:
+                        states["impossible"].append(f"s{state}")
+        
+        return states
+    
+    def extract_evaluation_world(self):
+        """Extract the main evaluation world.
+        
+        Returns:
+            State name (e.g., 's3') or None if not set
+        """
+        if hasattr(self, 'z3_main_world') and self.z3_main_world is not None:
+            if hasattr(self.z3_main_world, 'as_long'):
+                return f"s{self.z3_main_world.as_long()}"
+            else:
+                return f"s{self.z3_main_world}"
+        return None
+    
+    def extract_relations(self):
+        """Extract relations between states.
+        
+        For Exclusion, this includes exclusion/conflict relations.
+        
+        Returns:
+            Dict containing various relations
+        """
+        relations = {}
+        
+        # Extract exclusion relations if available
+        if hasattr(self, 'excludes_pairs') and self.excludes_pairs:
+            relations['excludes'] = []
+            for pair in self.excludes_pairs:
+                if len(pair) == 2:
+                    s1, s2 = pair
+                    if hasattr(s1, 'as_long'):
+                        s1_name = f"s{s1.as_long()}"
+                    else:
+                        s1_name = f"s{s1}"
+                    if hasattr(s2, 'as_long'):
+                        s2_name = f"s{s2.as_long()}"
+                    else:
+                        s2_name = f"s{s2}"
+                    relations['excludes'].append([s1_name, s2_name])
+        
+        return relations
+    
+    def extract_propositions(self):
+        """Extract proposition truth values at worlds.
+        
+        Returns:
+            Dict mapping propositions to their truth values at each world
+        """
+        propositions = {}
+        
+        if not hasattr(self, 'syntax') or not hasattr(self.syntax, 'propositions'):
+            return propositions
+        
+        # Get world states
+        worlds = []
+        if hasattr(self, 'all_world_bits'):
+            worlds = self.all_world_bits
+        
+        # Extract truth values for each proposition
+        for prop_name, prop_obj in self.syntax.propositions.items():
+            if hasattr(prop_obj, 'letter'):
+                letter = prop_obj.letter
+                propositions[letter] = {}
+                
+                for world in worlds:
+                    # Get world number
+                    if hasattr(world, 'as_long'):
+                        world_num = world.as_long()
+                    else:
+                        world_num = world
+                    
+                    world_name = f"s{world_num}"
+                    
+                    if hasattr(prop_obj, 'truth_value_at'):
+                        try:
+                            # Create eval point for this world
+                            eval_point = {"world": world}
+                            truth_value = prop_obj.truth_value_at(eval_point)
+                            # Evaluate the Z3 expression
+                            if hasattr(self, 'z3_model'):
+                                propositions[letter][world_name] = z3.is_true(
+                                    self.z3_model.evaluate(truth_value)
+                                )
+                        except:
+                            # If evaluation fails, skip this world
+                            pass
+        
+        return propositions
+    
+    def print_model_differences(self, output=sys.stdout):
+        """Print exclusion-specific model differences."""
+        if not hasattr(self, 'model_differences') or not self.model_differences:
+            return
+        
+        diffs = self.model_differences
+        
+        # Debug: print what keys we have
+        # print(f"DEBUG: model_differences keys: {list(diffs.keys())}", file=output)
+        
+        # Use colors if outputting to terminal
+        if output is sys.stdout:
+            GREEN = "\033[32m"
+            RED = "\033[31m"
+            YELLOW = "\033[33m"
+            BLUE = "\033[34m"
+            RESET = "\033[0m"
+        else:
+            GREEN = RED = YELLOW = BLUE = RESET = ""
+        
+        print(f"\n{YELLOW}=== DIFFERENCES FROM PREVIOUS MODEL ==={RESET}\n", file=output)
+        
+        # Print world changes - use 'world_changes' key from generic calculator
+        worlds = diffs.get('world_changes', {})
+        if worlds.get('added') or worlds.get('removed'):
+            print(f"{BLUE}World Changes:{RESET}", file=output)
+            for world in worlds.get('added', []):
+                world_str = bitvec_to_substates(world, self.N)
+                print(f"  {GREEN}+ {world_str} (now a world){RESET}", file=output)
+            for world in worlds.get('removed', []):
+                world_str = bitvec_to_substates(world, self.N)
+                print(f"  {RED}- {world_str} (no longer a world){RESET}", file=output)
+            print(file=output)
+        
+        # Print possible state changes
+        possible = diffs.get('possible_changes', {})
+        if possible.get('added') or possible.get('removed'):
+            print(f"{BLUE}Possible State Changes:{RESET}", file=output)
+            for state in possible.get('added', []):
+                state_str = bitvec_to_substates(state, self.N)
+                print(f"  {GREEN}+ {state_str} (now possible){RESET}", file=output)
+            for state in possible.get('removed', []):
+                state_str = bitvec_to_substates(state, self.N)
+                print(f"  {RED}- {state_str} (now impossible){RESET}", file=output)
+            print(file=output)
+        
+        # Print theory-specific differences if available
+        
+        # Verification changes
+        verifications = diffs.get('verifications', {})
+        if verifications:
+            print(f"{BLUE}Verification Changes:{RESET}", file=output)
+            for verification_key, change in verifications.items():
+                if change['new']:
+                    print(f"  {GREEN}+ {verification_key}{RESET}", file=output)
+                else:
+                    print(f"  {RED}- {verification_key}{RESET}", file=output)
+            print(file=output)
+        
+        # Exclusion relation changes
+        exclusions = diffs.get('exclusions', {})
+        if exclusions:
+            print(f"{BLUE}Exclusion Changes:{RESET}", file=output)
+            for exclusion_key, change in exclusions.items():
+                if change['new']:
+                    print(f"  {GREEN}+ {exclusion_key}{RESET}", file=output)
+                else:
+                    print(f"  {RED}- {exclusion_key}{RESET}", file=output)
+            print(file=output)
+        
+        # Witness function changes
+        witnesses = diffs.get('witnesses', {})
+        if witnesses and witnesses.get('changed_witnesses'):
+            print(f"{BLUE}Witness Function Changes:{RESET}", file=output)
+            for formula, changes in witnesses['changed_witnesses'].items():
+                print(f"  Formula: {formula}", file=output)
+                
+                # Show h function changes
+                h_changes = changes.get('h_changes', {})
+                if h_changes:
+                    print(f"    {YELLOW}h function:{RESET}", file=output)
+                    for state, change in h_changes.items():
+                        old_state = bitvec_to_substates(change['old'], self.N)
+                        new_state = bitvec_to_substates(change['new'], self.N) 
+                        print(f"      {state}: {old_state} → {new_state}", file=output)
+                
+                # Show y function changes
+                y_changes = changes.get('y_changes', {})
+                if y_changes:
+                    print(f"    {YELLOW}y function:{RESET}", file=output)
+                    for state, change in y_changes.items():
+                        old_state = bitvec_to_substates(change['old'], self.N)
+                        new_state = bitvec_to_substates(change['new'], self.N)
+                        print(f"      {state}: {old_state} → {new_state}", file=output)
+            print(file=output)
+
+
 class WitnessProposition(PropositionDefaults):
     """Proposition class for witness predicate semantics."""
     
@@ -1175,8 +1498,13 @@ class WitnessProposition(PropositionDefaults):
         # Check each state to see if it verifies the sentence
         for state in range(2**semantics.N):
             constraint = semantics.extended_verify(state, self.sentence, eval_point)
-            if z3.is_true(self.z3_model.evaluate(constraint)):
-                result.add(state)
+            # Use the model structure's _evaluate_z3_boolean method if available
+            if hasattr(self.model_structure, '_evaluate_z3_boolean'):
+                if self.model_structure._evaluate_z3_boolean(self.z3_model, constraint):
+                    result.add(state)
+            else:
+                if z3.is_true(self.z3_model.evaluate(constraint)):
+                    result.add(state)
         return result
         
     def truth_value_at(self, eval_point):
@@ -1194,11 +1522,19 @@ class WitnessProposition(PropositionDefaults):
         N = self.model_structure.semantics.N
         possible = self.model_structure.semantics.possible
         z3_model = self.model_structure.z3_model
-        ver_states = {
-            bitvec_to_substates(bit, N)
-            for bit in self.verifiers
-            if z3.is_true(z3_model.evaluate(possible(bit))) or self.settings.get('print_impossible', False)
-        }
+        # Use the model structure's _evaluate_z3_boolean method if available
+        if hasattr(self.model_structure, '_evaluate_z3_boolean'):
+            ver_states = {
+                bitvec_to_substates(bit, N)
+                for bit in self.verifiers
+                if self.model_structure._evaluate_z3_boolean(z3_model, possible(bit)) or self.settings.get('print_impossible', False)
+            }
+        else:
+            ver_states = {
+                bitvec_to_substates(bit, N)
+                for bit in self.verifiers
+                if z3.is_true(z3_model.evaluate(possible(bit))) or self.settings.get('print_impossible', False)
+            }
         return pretty_set_print(ver_states)
         
     def print_proposition(self, eval_point, indent_num, use_colors):
@@ -1207,7 +1543,11 @@ class WitnessProposition(PropositionDefaults):
         
         N = self.model_structure.semantics.N
         z3_formula = self.truth_value_at(eval_point)
-        truth_value = z3.is_true(self.model_structure.z3_model.evaluate(z3_formula))
+        # Use the model structure's _evaluate_z3_boolean method if available
+        if hasattr(self.model_structure, '_evaluate_z3_boolean'):
+            truth_value = self.model_structure._evaluate_z3_boolean(self.model_structure.z3_model, z3_formula)
+        else:
+            truth_value = z3.is_true(self.model_structure.z3_model.evaluate(z3_formula))
         world_state = bitvec_to_substates(eval_point["world"], N)
         RESET, FULL, PART = self.set_colors(self.name, indent_num, truth_value, world_state, use_colors)
         print(
