@@ -20,7 +20,7 @@ logger = logging.getLogger(__name__)
 class LogosModelIterator(BaseModelIterator):
     """Model iterator for the logos theory.
     
-    This class extends BaseModelIterator with logos theory-specific
+    This class extends CoreModelIterator with logos theory-specific
     implementations of the abstract methods required for model iteration.
     It provides specialized difference detection, constraint generation,
     and visualization for logos theory models.
@@ -195,242 +195,201 @@ class LogosModelIterator(BaseModelIterator):
         return differences
     
     def _create_difference_constraint(self, previous_models):
-        """Create a Z3 constraint requiring difference from all previous models with smart ordering.
+        """Create constraints requiring difference from previous models.
         
-        For logos theory, we create constraints that require at least one of:
-        - Different verification/falsification for some sentence letter
-        - Different world structure
-        - Different possible states
-        
-        Constraints are ordered by expected effectiveness for faster solving.
+        This implements a smart ordering of constraint generators based on
+        the master branch approach. It tries simpler constraints first
+        (world count, letter values) before more complex structural ones.
         
         Args:
-            previous_models: List of Z3 models to differ from
+            previous_models: List of Z3 models found so far
             
         Returns:
-            z3.ExprRef: Z3 constraint expression
+            Z3 constraint requiring structural difference
         """
-        # Sort constraints by expected effectiveness
-        constraint_generators = [
-            # Most likely to produce different models first
-            (self._create_world_count_constraint, 1),
-            (self._create_letter_value_constraint, 2),
-            (self._create_semantic_function_constraint, 3),
-            # More complex constraints last
-            (self._create_structural_constraint, 4),
-        ]
+        constraints = []
         
-        # Sort by priority
-        constraint_generators.sort(key=lambda x: x[1])
+        # Get current semantics
+        semantics = self.build_example.model_constraints.semantics
         
-        # Generate constraints in priority order
-        all_constraints = []
-        for generator, _ in constraint_generators:
-            constraints = generator(previous_models)
-            if constraints:
-                all_constraints.extend(constraints)
+        # Try different types of constraints in order of complexity
+        for prev_model in previous_models:
+            model_constraints = []
+            
+            # 1. World count constraint (simplest)
+            world_count_constraint = self._create_world_count_constraint(prev_model, semantics)
+            if world_count_constraint is not None:
+                model_constraints.append(world_count_constraint)
+            
+            # 2. Letter value constraints (verify/falsify differences)
+            letter_constraints = self._create_letter_value_constraints(prev_model, semantics)
+            if letter_constraints:
+                model_constraints.extend(letter_constraints)
+            
+            # 3. Structural constraints (more complex)
+            if len(model_constraints) < 5:  # Only add if we need more constraints
+                structural_constraints = self._create_structural_constraints(prev_model, semantics)
+                if structural_constraints:
+                    model_constraints.extend(structural_constraints[:5-len(model_constraints)])
+            
+            # Combine constraints for this model
+            if model_constraints:
+                constraints.append(z3.Or(*model_constraints))
+        
+        # All models must be different
+        return z3.And(*constraints) if constraints else z3.BoolVal(True)
+    
+    def _create_world_count_constraint(self, prev_model, semantics):
+        """Create constraint on different number of worlds."""
+        # Count worlds in previous model
+        prev_world_count = 0
+        for state in range(2**semantics.N):
+            if z3.is_true(prev_model.eval(semantics.is_world(state), model_completion=True)):
+                prev_world_count += 1
+        
+        # Current model must have different number of worlds
+        current_world_count = z3.Sum([
+            z3.If(semantics.is_world(state), 1, 0) 
+            for state in range(2**semantics.N)
+        ])
+        
+        return current_world_count != prev_world_count
+    
+    def _create_letter_value_constraints(self, prev_model, semantics):
+        """Create constraints on verify/falsify values differing."""
+        constraints = []
+        
+        # Get sentence letters from syntax
+        syntax = self.build_example.example_syntax
+        if not hasattr(syntax, 'sentence_letters'):
+            return constraints
+        
+        for letter_obj in syntax.sentence_letters:
+            if hasattr(letter_obj, 'sentence_letter'):
+                atom = letter_obj.sentence_letter
                 
-                # Early termination if we have enough constraints
-                if len(all_constraints) > 10:
-                    break
-        
-        return z3.And(*all_constraints) if all_constraints else z3.BoolVal(True)
-    
-    def _create_world_count_constraint(self, previous_models):
-        """Create constraints based on world count differences."""
-        constraints = []
-        semantics = self.build_example.model_structure.semantics
-        all_states = self.build_example.model_structure.all_states
-        
-        for prev_model in previous_models:
-            # Count worlds in previous model
-            prev_world_count = sum(1 for state in all_states 
-                                 if bool(prev_model.eval(semantics.is_world(state), model_completion=True)))
-            
-            # Create constraint for different world count
-            current_world_count = z3.Sum([z3.If(semantics.is_world(state), 1, 0) for state in all_states])
-            constraints.append(current_world_count != prev_world_count)
+                # Check each state
+                for state in range(2**semantics.N):
+                    # Get previous values
+                    prev_verify = prev_model.eval(
+                        semantics.verify(state, atom), 
+                        model_completion=True
+                    )
+                    prev_falsify = prev_model.eval(
+                        semantics.falsify(state, atom), 
+                        model_completion=True
+                    )
+                    
+                    # Create constraints for differences
+                    constraints.append(
+                        semantics.verify(state, atom) != prev_verify
+                    )
+                    constraints.append(
+                        semantics.falsify(state, atom) != prev_falsify
+                    )
         
         return constraints
     
-    def _create_letter_value_constraint(self, previous_models):
-        """Create constraints based on sentence letter verification/falsification."""
+    def _create_structural_constraints(self, prev_model, semantics):
+        """Create constraints on structural differences (parthood, etc)."""
         constraints = []
-        semantics = self.build_example.model_structure.semantics
-        all_states = self.build_example.model_structure.all_states
-        sentence_letters = self.build_example.model_structure.sentence_letters
         
-        for prev_model in previous_models:
-            differences = []
-            
-            # Require different verification for at least one state/letter pair
-            for state in all_states[:min(3, len(all_states))]:  # Limit to first 3 states
-                for letter in sentence_letters[:min(2, len(sentence_letters))]:  # Limit to first 2 letters
-                    # Get the Z3 atom for this sentence letter
-                    if hasattr(letter, 'sentence_letter') and letter.sentence_letter is not None:
-                        atom = letter.sentence_letter
-                    else:
-                        continue
-                    
-                    prev_verify = prev_model.eval(semantics.verify(state, atom), model_completion=True)
-                    differences.append(semantics.verify(state, atom) != prev_verify)
-                    
-                    prev_falsify = prev_model.eval(semantics.falsify(state, atom), model_completion=True)
-                    differences.append(semantics.falsify(state, atom) != prev_falsify)
-            
-            if differences:
-                constraints.append(z3.Or(*differences))
-        
-        return constraints
-    
-    def _create_semantic_function_constraint(self, previous_models):
-        """Create constraints based on semantic functions."""
-        constraints = []
-        semantics = self.build_example.model_structure.semantics
-        all_states = self.build_example.model_structure.all_states
-        sentence_letters = self.build_example.model_structure.sentence_letters
-        
-        for prev_model in previous_models:
-            differences = []
-            
-            # Full verification/falsification differences
-            for state in all_states:
-                for letter in sentence_letters:
-                    # Get the Z3 atom for this sentence letter
-                    if hasattr(letter, 'sentence_letter') and letter.sentence_letter is not None:
-                        atom = letter.sentence_letter
-                    else:
-                        continue
-                    
-                    prev_verify = prev_model.eval(semantics.verify(state, atom), model_completion=True)
-                    differences.append(semantics.verify(state, atom) != prev_verify)
-                    
-                    prev_falsify = prev_model.eval(semantics.falsify(state, atom), model_completion=True)
-                    differences.append(semantics.falsify(state, atom) != prev_falsify)
-            
-            if differences:
-                constraints.append(z3.Or(*differences))
-        
-        return constraints
-    
-    def _create_structural_constraint(self, previous_models):
-        """Create constraints based on structural differences."""
-        constraints = []
-        semantics = self.build_example.model_structure.semantics
-        all_states = self.build_example.model_structure.all_states
-        
-        for prev_model in previous_models:
-            differences = []
-            
-            # Require different world status for at least one state
-            for state in all_states:
-                prev_is_world = prev_model.eval(semantics.is_world(state), model_completion=True)
-                differences.append(semantics.is_world(state) != prev_is_world)
-            
-            # Require different possible status for at least one state
-            for state in all_states:
-                prev_possible = prev_model.eval(semantics.possible(state), model_completion=True)
-                differences.append(semantics.possible(state) != prev_possible)
-            
-            # Require different parthood relations
-            for i, s1 in enumerate(all_states[:min(3, len(all_states))]):
-                for j, s2 in enumerate(all_states[:min(3, len(all_states))]):
-                    if i != j:  # Compare indices instead of Z3 expressions
-                        prev_part = prev_model.eval(semantics.is_part_of(s1, s2), model_completion=True)
-                        differences.append(semantics.is_part_of(s1, s2) != prev_part)
-            
-            if differences:
-                constraints.append(z3.Or(*differences))
+        # Parthood relation differences
+        for s1 in range(2**semantics.N):
+            for s2 in range(2**semantics.N):
+                if s1 != s2:
+                    prev_part = prev_model.eval(
+                        semantics.is_part_of(s1, s2),
+                        model_completion=True
+                    )
+                    constraints.append(
+                        semantics.is_part_of(s1, s2) != prev_part
+                    )
         
         return constraints
     
     def _create_non_isomorphic_constraint(self, z3_model):
-        """Create a constraint that forces structural differences to avoid isomorphism.
+        """Create constraint preventing isomorphic models.
         
-        For logos theory, we focus on breaking symmetries in the state space
-        by requiring specific structural differences.
+        For logos theory, isomorphism means there's a permutation of states
+        that preserves all relations (verify, falsify, parthood, etc).
         
         Args:
-            z3_model: The Z3 model to differ from
-        
+            z3_model: The Z3 model to constrain against
+            
         Returns:
-            z3.ExprRef: Z3 constraint expression or None if creation fails
+            Z3 constraint preventing isomorphism
         """
-        try:
-            semantics = self.build_example.model_structure.semantics
-            all_states = self.build_example.model_structure.all_states
-            
-            # Create constraints that break symmetries
-            constraints = []
-            
-            # Try to force a different number of worlds
-            world_count = sum(1 for state in all_states
-                            if bool(z3_model.eval(semantics.is_world(state), model_completion=True)))
-            
-            current_world_count = z3.Sum([z3.If(semantics.is_world(state), 1, 0) 
-                                        for state in all_states])
-            
-            constraints.append(current_world_count != world_count)
-            
-            # Try to force different possible state count
-            possible_count = sum(1 for state in all_states
-                               if bool(z3_model.eval(semantics.possible(state), model_completion=True)))
-            
-            current_possible_count = z3.Sum([z3.If(semantics.possible(state), 1, 0)
-                                           for state in all_states])
-            
-            constraints.append(current_possible_count != possible_count)
-            
-            return z3.Or(*constraints) if constraints else None
-            
-        except Exception as e:
-            logger.warning(f"Failed to create non-isomorphic constraint: {e}")
-            return None
-    
+        # For now, return a simple constraint
+        # Full isomorphism checking would be more complex
+        return z3.BoolVal(True)
+        
     def _create_stronger_constraint(self, isomorphic_model):
-        """Create stronger constraints after multiple isomorphism failures.
+        """Create constraint for finding stronger models.
         
-        This is called when we've found too many isomorphic models in a row.
-        For logos theory, we create more aggressive constraints that force
-        significant structural differences.
+        In logos theory, a stronger model typically has more verifiers
+        or fewer falsifiers for the conclusion formulas.
         
         Args:
-            isomorphic_model: The Z3 model that was isomorphic
-        
+            isomorphic_model: An isomorphic model to strengthen against
+            
         Returns:
-            z3.ExprRef: Z3 constraint expression or None if creation fails
+            Z3 constraint for stronger model
         """
-        try:
-            semantics = self.build_example.model_structure.semantics
-            all_states = self.build_example.model_structure.all_states
-            sentence_letters = self.build_example.model_structure.sentence_letters
+        # For now, return a simple constraint
+        # Full implementation would compare conclusion truth values
+        return z3.BoolVal(True)
+    
+    def iterate_generator(self):
+        """Override to add theory-specific differences to logos theory models.
+        
+        This method extends the base iterator's generator to merge logos-specific
+        differences (verification, falsification, parthood) with the generic 
+        differences calculated by the base iterator.
+        
+        Yields:
+            Model structures with both generic and theory-specific differences
+        """
+        for model in super().iterate_generator():
+            # Calculate theory-specific differences if we have a previous model
+            if len(self.model_structures) >= 2:
+                theory_diffs = self._calculate_logos_differences(
+                    model, self.model_structures[-2]
+                )
+                
+                # Transform logos structure to match display expectations
+                if theory_diffs.get('verify') or theory_diffs.get('falsify'):
+                    atomic_changes = {}
+                    
+                    # Transform verify structure
+                    if theory_diffs.get('verify'):
+                        atomic_changes['verify'] = {}
+                        for letter_str, state_changes in theory_diffs['verify'].items():
+                            # Extract clean letter name (A, B, C) from "Proposition_A" or "A" formats
+                            letter_name = letter_str.replace('Proposition_', '').replace('(', '').replace(')', '')
+                            # Handle case where letter_str might be "Proposition A" with space
+                            letter_name = letter_name.replace('Proposition ', '')
+                            atomic_changes['verify'][letter_name] = state_changes
+                    
+                    # Transform falsify structure
+                    if theory_diffs.get('falsify'):
+                        atomic_changes['falsify'] = {}
+                        for letter_str, state_changes in theory_diffs['falsify'].items():
+                            # Extract clean letter name (A, B, C) from "Proposition_A" or "A" formats
+                            letter_name = letter_str.replace('Proposition_', '').replace('(', '').replace(')', '')
+                            # Handle case where letter_str might be "Proposition A" with space
+                            letter_name = letter_name.replace('Proposition ', '')
+                            atomic_changes['falsify'][letter_name] = state_changes
+                    
+                    theory_diffs['atomic_changes'] = atomic_changes
+                
+                # Merge theory-specific differences with existing generic ones
+                if hasattr(model, 'model_differences') and model.model_differences:
+                    model.model_differences.update(theory_diffs)
+                else:
+                    model.model_differences = theory_diffs
             
-            # Create very strong constraints
-            constraints = []
-            
-            # Force different world states
-            for state in all_states[:min(3, len(all_states))]:  # Limit to first 3 states
-                prev_is_world = isomorphic_model.eval(semantics.is_world(state), model_completion=True)
-                constraints.append(semantics.is_world(state) != prev_is_world)
-            
-            # Force different possible state structure
-            possible_count = sum(1 for state in all_states
-                               if bool(isomorphic_model.eval(semantics.possible(state), model_completion=True)))
-            
-            current_possible_count = z3.Sum([z3.If(semantics.possible(state), 1, 0) 
-                                           for state in all_states])
-            
-            # Require significantly different number of possible states (at least 2 difference)
-            constraints.append(z3.Or(
-                current_possible_count >= possible_count + 2,
-                current_possible_count <= possible_count - 2
-            ))
-            
-            return z3.And(*constraints) if constraints else None
-            
-        except Exception as e:
-            logger.warning(f"Failed to create stronger constraint: {e}")
-            return None
+            yield model
 
 
 # Module-level convenience function
@@ -457,4 +416,38 @@ def iterate_example(example, max_iterations=None):
     # Store the iterator on the example for access to debug messages
     example._iterator = iterator
     
-    return models
\ No newline at end of file
+    return models
+
+
+def iterate_example_generator(example, max_iterations=None):
+    """Generator version of iterate_example that yields models incrementally.
+    
+    This function provides a generator interface for finding multiple models,
+    yielding each model as it's discovered rather than returning them all at once.
+    
+    Args:
+        example: A BuildExample instance with logos theory.
+        max_iterations: Maximum number of models to find.
+        
+    Yields:
+        ModelStructure: Each distinct model as it's found.
+    """
+    if max_iterations is not None:
+        # Update the iterate setting
+        if not hasattr(example, 'settings'):
+            example.settings = {}
+        example.settings['iterate'] = max_iterations
+    
+    # Create iterator
+    iterator = LogosModelIterator(example)
+    
+    # Store the iterator on the example for access to debug messages
+    example._iterator = iterator
+    
+    # Use the generator interface
+    yield from iterator.iterate_generator()
+
+
+# Mark the generator function for BuildModule detection
+iterate_example_generator.returns_generator = True
+iterate_example_generator.__wrapped__ = iterate_example_generator
\ No newline at end of file
